@@ -42,9 +42,9 @@ $^V eq v5.8.4
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Tue Nov  2 18:35:29 CET 2004
+## Configuration time: Sun Jan 30 17:56:47 CET 2005
 ## Configured by     : Debian Project
-## Target system     : gnu debian 0.3 gnu-mach 1.3hurd-0.3 i386-at386 gnu 
+## Target system     : gnu nighthawk 0.3 gnu-mach 1.3hurd-0.3 i686-at386 gnu 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -168,7 +168,7 @@ ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=5 __GNUC__=3'
 ccversion=''
 cf_by='Debian Project'
 cf_email='perl@packages.debian.org'
-cf_time='Tue Nov  2 18:35:29 CET 2004'
+cf_time='Sun Jan 30 17:56:47 CET 2005'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -887,10 +887,10 @@ modetype='mode_t'
 more='more'
 multiarch='undef'
 mv=''
-myarchname='i386-AT386-gnu'
+myarchname='i686-AT386-gnu'
 mydomain=''
 myhostname='localhost'
-myuname='gnu debian 0.3 gnu-mach 1.3hurd-0.3 i386-at386 gnu '
+myuname='gnu nighthawk 0.3 gnu-mach 1.3hurd-0.3 i686-at386 gnu '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
